<?php

return [
    'Names' => [
        'aa' => 'আফাৰ',
        'ab' => 'আবখাজিয়ান',
        'ace' => 'আচিনিজ',
        'ada' => 'আদাংমে',
        'ady' => 'আদিগে',
        'af' => 'আফ্ৰিকানছ্',
        'agq' => 'আঘেম',
        'ain' => 'আইনু',
        'ak' => 'আকান',
        'ale' => 'আলেউট',
        'alt' => 'দাক্ষিণাত্য আল্টাই',
        'am' => 'আমহাৰিক',
        'an' => 'আৰ্গোনিজ',
        'ann' => 'অ’ব’ল’',
        'anp' => 'আঙ্গিকা',
        'ar' => 'আৰবী',
        'arn' => 'মাপুচে',
        'arp' => 'আৰাপাহো',
        'ars' => 'নাজডি আৰবী',
        'as' => 'অসমীয়া',
        'asa' => 'আছু',
        'ast' => 'এষ্টুৰীয়',
        'atj' => 'আতিকামেক',
        'av' => 'আভেৰিক',
        'awa' => 'অৱধী',
        'ay' => 'আয়মাৰা',
        'az' => 'আজেৰবাইজানী',
        'ba' => 'বাছখিৰ',
        'ban' => 'বালিনীজ',
        'bas' => 'বাছা',
        'be' => 'বেলাৰুছীয়',
        'bem' => 'বেম্বা',
        'bez' => 'বেনা',
        'bg' => 'বুলগেৰীয়',
        'bho' => 'ভোজপুৰী',
        'bi' => 'বিছলামা',
        'bin' => 'বিনি',
        'bla' => 'ছিক্সিকা',
        'bm' => 'বামবাৰা',
        'bn' => 'বাংলা',
        'bo' => 'তিব্বতী',
        'br' => 'ব্ৰেটন',
        'brx' => 'বড়ো',
        'bs' => 'বছনীয়',
        'bug' => 'বগিনীজ',
        'byn' => 'ব্লিন',
        'ca' => 'কাতালান',
        'cay' => 'কায়ুগা',
        'ccp' => 'চাক্‌মা',
        'ce' => 'চেচেন',
        'ceb' => 'চিবুৱানো',
        'cgg' => 'চিগা',
        'ch' => 'চামোৰো',
        'chk' => 'চুকিজ',
        'chm' => 'মাৰি',
        'cho' => 'চোক্টাউ',
        'chp' => 'চিপেউয়ান',
        'chr' => 'চেৰোকি',
        'chy' => 'চাইয়েন',
        'ckb' => 'চেণ্ট্ৰেল কুৰ্ডিচ',
        'clc' => 'চিলক’টিন',
        'co' => 'কোৰ্ছিকান',
        'crg' => 'মিচিফ',
        'crj' => 'দাক্ষিণাত্য ইষ্ট ক্ৰী',
        'crk' => 'প্লেইনছ ক্ৰী',
        'crl' => 'নৰ্দাৰ্ন ইষ্ট ক্ৰী',
        'crm' => 'মুজ ক্ৰী',
        'crr' => 'কেৰ’লিনা আলগংকিয়ান',
        'crs' => 'ছেছেলৱা ক্ৰিওল ফ্ৰেন্স',
        'cs' => 'চেক',
        'csw' => 'স্বাম্পী ক্ৰী',
        'cu' => 'চাৰ্চ শ্লেভিক',
        'cv' => 'চুভাচ',
        'cy' => 'ৱেলচ',
        'da' => 'ডেনিচ',
        'dak' => 'ডাকোটা',
        'dar' => 'দাৰ্গৱা',
        'dav' => 'তেইতা',
        'de' => 'জাৰ্মান',
        'dgr' => 'ডোগ্ৰিব',
        'dje' => 'ঝাৰ্মা',
        'doi' => 'ডোগ্ৰী',
        'dsb' => 'ল’ৱাৰ ছোৰ্বিয়ান',
        'dua' => 'ডুৱালা',
        'dv' => 'দিবেহি',
        'dyo' => 'জোলা-ফ’নি',
        'dz' => 'জোংখা',
        'dzg' => 'দাজাগা',
        'ebu' => 'এম্বু',
        'ee' => 'ইৱে',
        'efi' => 'এফিক',
        'eka' => 'একাজুক',
        'el' => 'গ্ৰীক',
        'en' => 'ইংৰাজী',
        'eo' => 'এস্পেৰান্তো',
        'es' => 'স্পেনিচ',
        'et' => 'এষ্টোনিয়',
        'eu' => 'বাস্ক',
        'ewo' => 'ইওন্দো',
        'fa' => 'ফাৰ্ছী',
        'ff' => 'ফুলাহ',
        'fi' => 'ফিনিচ',
        'fil' => 'ফিলিপিনো',
        'fj' => 'ফিজিয়ান',
        'fo' => 'ফাৰোইজ',
        'fon' => 'ফ’ন',
        'fr' => 'ফ্ৰেন্স',
        'frc' => 'কেজ’ন ফৰাছী',
        'frr' => 'নৰ্দাৰ্ন ফ্ৰিছিয়ান',
        'fur' => 'ফ্ৰিউলিয়ান',
        'fy' => 'ৱেষ্টাৰ্ণ ফ্ৰিছিয়ান',
        'ga' => 'আইৰিচ',
        'gaa' => 'গা',
        'gd' => 'স্কটিচ গেইলিক',
        'gez' => 'গীজ',
        'gil' => 'গিলবাৰ্টিছ',
        'gl' => 'গেলিচিয়ান',
        'gn' => 'গুৱাৰাণী',
        'gor' => 'গোৰোন্তালো',
        'gsw' => 'ছুইচ জাৰ্মান',
        'gu' => 'গুজৰাটী',
        'guz' => 'গুছি',
        'gv' => 'মেংক্স',
        'gwi' => 'জিউইচিন',
        'ha' => 'হাউছা',
        'hai' => 'হেইডা',
        'haw' => 'হাৱাই',
        'hax' => 'দাক্ষিণাত্যৰ হাইডা',
        'he' => 'হিব্ৰু',
        'hi' => 'হিন্দী',
        'hil' => 'হিলিগায়নোন',
        'hmn' => 'হমং',
        'hr' => 'ক্ৰোৱেচিয়ান',
        'hsb' => 'আপাৰ ছোৰ্বিয়ান',
        'ht' => 'হেইটিয়ান ক্ৰিয়ল',
        'hu' => 'হাঙ্গেৰিয়ান',
        'hup' => 'হুপা',
        'hur' => 'হেলকোমেলেম',
        'hy' => 'আৰ্মেনীয়',
        'hz' => 'হেৰেৰো',
        'ia' => 'ইণ্টাৰলিংগুৱা',
        'iba' => 'ইবান',
        'ibb' => 'ইবিবিও',
        'id' => 'ইণ্ডোনেচিয়',
        'ig' => 'ইগ্বো',
        'ii' => 'ছিচুৱান ই',
        'ikt' => 'ৱেষ্টাৰ্ণ কানাডিয়ান ইনক্টিটুট',
        'ilo' => 'ইলোকো',
        'inh' => 'ইংগুচ',
        'io' => 'ইডো',
        'is' => 'আইচলেণ্ডিক',
        'it' => 'ইটালিয়ান',
        'iu' => 'ইনুক্টিটুট',
        'ja' => 'জাপানী',
        'jbo' => 'লোজ্বান',
        'jgo' => 'নগোম্বা',
        'jmc' => 'মেকহেম',
        'jv' => 'জাভানী',
        'ka' => 'জৰ্জিয়ান',
        'kab' => 'কাবাইল',
        'kac' => 'কাচিন',
        'kaj' => 'জজু',
        'kam' => 'কাম্বা',
        'kbd' => 'কাবাৰ্ডিয়ান',
        'kcg' => 'ত্যাপ',
        'kde' => 'মাকোণ্ড',
        'kea' => 'কাবুভেৰ্ডিয়ানু',
        'kfo' => 'কোৰো',
        'kgp' => 'কেইংগাং',
        'kha' => 'খাচি',
        'khq' => 'কোয়াৰ চিনি',
        'ki' => 'কিকুয়ু',
        'kj' => 'কুয়ানিয়ামা',
        'kk' => 'কাজাখ',
        'kkj' => 'কাকো',
        'kl' => 'কালালিছুট',
        'kln' => 'কালেনজিন',
        'km' => 'খমেৰ',
        'kmb' => 'কিম্বুন্দু',
        'kn' => 'কানাড়া',
        'ko' => 'কোৰিয়ান',
        'kok' => 'কোংকণী',
        'kpe' => 'কেপেল',
        'kr' => 'কানুৰি',
        'krc' => 'কাৰাচে-বাল্কাৰ',
        'krl' => 'কেৰেলিয়ান',
        'kru' => 'কুৰুখ',
        'ks' => 'কাশ্মিৰী',
        'ksb' => 'চাম্বালা',
        'ksf' => 'বাফিয়া',
        'ksh' => 'কোলোগনিয়ান',
        'ku' => 'কুৰ্ডিচ',
        'kum' => 'কুমিক',
        'kv' => 'কোমি',
        'kw' => 'কোৰ্নিচ',
        'kwk' => 'ক্বাকৱালা',
        'ky' => 'কিৰ্গিজ',
        'la' => 'লেটিন',
        'lad' => 'লাডিনো',
        'lag' => 'লাংগি',
        'lb' => 'লাক্সেমবাৰ্গিচ',
        'lez' => 'লেজঘিয়ান',
        'lg' => 'গান্দা',
        'li' => 'লিম্বুৰ্গিচ',
        'lil' => 'লিল্লোৱেট',
        'lkt' => 'লাকোটা',
        'ln' => 'লিংগালা',
        'lo' => 'লাও',
        'lou' => 'লুইজিয়ানা কেৰ’ল',
        'loz' => 'লোজি',
        'lrc' => 'উদীচ্য লুৰি',
        'lsm' => 'চামিয়া',
        'lt' => 'লিথুৱানিয়ান',
        'lu' => 'লুবা-কাটাংগা',
        'lua' => 'লুবা-লুলুৱা',
        'lun' => 'লুণ্ডা',
        'luo' => 'লুও',
        'lus' => 'মিজো',
        'luy' => 'লুইয়া',
        'lv' => 'লাটভিয়ান',
        'mad' => 'মাদুৰেছে',
        'mag' => 'মাগাহি',
        'mai' => 'মৈথিলী',
        'mak' => 'মাকাছাৰ',
        'mas' => 'মাছাই',
        'mdf' => 'মোক্সা',
        'men' => 'মেণ্ডে',
        'mer' => 'মেৰু',
        'mfe' => 'মৰিছিয়ান',
        'mg' => 'মালাগাছী',
        'mgh' => 'মাখুৱা-মিট্টো',
        'mgo' => 'মেটা',
        'mh' => 'মাৰ্চলিজ',
        'mi' => 'মাওৰি',
        'mic' => 'মিকমেক',
        'min' => 'মিনাংকাবাউ',
        'mk' => 'মেচিডোনীয়',
        'ml' => 'মালায়ালম',
        'mn' => 'মংগোলীয়',
        'mni' => 'মণিপুৰী',
        'moe' => 'ইন্নু-আইমুন',
        'moh' => 'মোহোক',
        'mos' => 'মোছি',
        'mr' => 'মাৰাঠী',
        'ms' => 'মালয়',
        'mt' => 'মাল্টিজ',
        'mua' => 'মুণ্ডাং',
        'mus' => 'ক্ৰীক',
        'mwl' => 'মিৰাণ্ডিজ',
        'my' => 'বাৰ্মীজ',
        'myv' => 'এৰজিয়া',
        'mzn' => 'মাজেন্দাৰানি',
        'na' => 'নাউৰু',
        'nap' => 'নিয়াপোলিটেন',
        'naq' => 'নামা',
        'nb' => 'নৰৱেজিয়ান বোকমাল',
        'nd' => 'উত্তৰ নিবেবেলে',
        'nds' => 'ল’ জাৰ্মান',
        'ne' => 'নেপালী',
        'new' => 'নেৱাৰি',
        'ng' => 'এন্দোঙ্গা',
        'nia' => 'নিয়াছ',
        'niu' => 'নিয়ুৱান',
        'nl' => 'ডাচ',
        'nmg' => 'কোৱাছিঅ’',
        'nn' => 'নৰৱেজিয়ান নায়নোৰ্স্ক',
        'nnh' => 'নিয়েম্বোন',
        'no' => 'নৰৱেজিয়ান',
        'nog' => 'নোগাই',
        'nqo' => 'এন্কো',
        'nr' => 'দক্ষিণ দেবেল',
        'nso' => 'উদীচ্য ছোথো',
        'nus' => 'নুয়েৰ',
        'nv' => 'নাভাজো',
        'ny' => 'ন্যাঞ্জা',
        'nyn' => 'ন্যানকোল',
        'oc' => 'অ’চিটান',
        'ojb' => 'নৰ্থ-ৱেষ্টাৰ্ণ অজিবৱা',
        'ojc' => 'চেন্ট্ৰেক অজিবৱা',
        'ojs' => 'অ’জি-ক্ৰী',
        'ojw' => 'ৱেষ্টাৰ্ণ অজিবৱা',
        'oka' => 'অ’কানাগান',
        'om' => 'ওৰোমো',
        'or' => 'ওড়িয়া',
        'os' => 'ওছেটিক',
        'pa' => 'পাঞ্জাবী',
        'pag' => 'পংগাছিনান',
        'pam' => 'পাম্পান্গা',
        'pap' => 'পাপিয়ামেণ্টো',
        'pau' => 'পালাউৱান',
        'pcm' => 'নাইজেৰিয়ান পিজিন',
        'pis' => 'পিজিন',
        'pl' => 'প’লিচ',
        'pqm' => 'মালিছীট-পাছামাকু’ডী',
        'prg' => 'প্ৰুছিয়ান',
        'ps' => 'পুস্ত',
        'pt' => 'পৰ্তুগীজ',
        'qu' => 'কুৱেচুৱা',
        'quc' => 'কিচিয়ে',
        'rap' => 'ৰাপানুই',
        'rar' => 'ৰাৰোতোঙ্গন',
        'rhg' => 'ৰোহিঙ্গিয়া',
        'rm' => 'ৰোমানচ',
        'rn' => 'ৰুন্দি',
        'ro' => 'ৰোমানীয়',
        'rof' => 'ৰোম্বো',
        'ru' => 'ৰাছিয়ান',
        'rup' => 'আৰোমানীয়',
        'rw' => 'কিনয়াৰোৱাণ্ডা',
        'rwk' => 'ৰৱা',
        'sa' => 'সংস্কৃত',
        'sad' => 'ছান্দাৱে',
        'sah' => 'ছাখা',
        'saq' => 'ছাম্বুৰু',
        'sat' => 'চাওতালি',
        'sba' => 'নাংম্বে',
        'sbp' => 'ছাঙ্গু',
        'sc' => 'ছাৰ্ডিনিয়ান',
        'scn' => 'ছিচিলিয়ান',
        'sco' => 'স্কটছ',
        'sd' => 'সিন্ধী',
        'se' => 'উদীচ্য ছামি',
        'seh' => 'ছেনা',
        'ses' => 'কোইৰাবোৰো চেন্নি',
        'sg' => 'ছাঙ্গো',
        'shi' => 'তাচেলহিট',
        'shn' => 'চান',
        'si' => 'সিংহলা',
        'sk' => 'শ্লোভাক',
        'sl' => 'শ্লোভেনিয়ান',
        'slh' => 'দাক্ষিণাত্যৰ লুছুটচীড',
        'sm' => 'ছামোন',
        'sma' => 'দাক্ষিণাত্য ছামি',
        'smj' => 'লুলে ছামি',
        'smn' => 'ইনাৰি ছামি',
        'sms' => 'স্কোল্ট ছামি',
        'sn' => 'চোনা',
        'snk' => 'ছোনিনকে',
        'so' => 'ছোমালি',
        'sq' => 'আলবেনীয়',
        'sr' => 'ছাৰ্বিয়ান',
        'srn' => 'স্ৰানান টোঙ্গো',
        'ss' => 'স্বাতি',
        'ssy' => 'ছাহো',
        'st' => 'দাক্ষিণাত্য ছোথো',
        'str' => 'ষ্ট্ৰেইটছ ছেলিশ্ব',
        'su' => 'ছুণ্ডানীজ',
        'suk' => 'ছুকুমা',
        'sv' => 'ছুইডিচ',
        'sw' => 'স্বাহিলি',
        'swb' => 'কোমোৰিয়ান',
        'syr' => 'চিৰিয়াক',
        'ta' => 'তামিল',
        'tce' => 'দাক্ষিণাত্যৰ টুটচ’ন',
        'te' => 'তেলুগু',
        'tem' => 'টিম্নে',
        'teo' => 'তেছো',
        'tet' => 'তেতুম',
        'tg' => 'তাজিক',
        'tgx' => 'টেগিশ্ব',
        'th' => 'থাই',
        'tht' => 'টাহলটান',
        'ti' => 'টিগৰিনিয়া',
        'tig' => 'তাইগ্ৰে',
        'tk' => 'তুৰ্কমেন',
        'tlh' => 'ক্লিংগন',
        'tli' => 'লিংগিট',
        'tn' => 'ছোৱানা',
        'to' => 'টোঙ্গান',
        'tok' => 'ট’কি প’না',
        'tpi' => 'টোক পিছিন',
        'tr' => 'তুৰ্কী',
        'trv' => 'তাৰোকো',
        'ts' => 'ছোঙ্গা',
        'tt' => 'তাতাৰ',
        'ttm' => 'নৰ্দাৰ্ন টুটচ’ন',
        'tum' => 'তুম্বুকা',
        'tvl' => 'টুভালু',
        'twq' => 'টাছাৱাক',
        'ty' => 'তাহিতিয়ান',
        'tyv' => 'তুভিনিয়ান',
        'tzm' => 'চেণ্ট্ৰেল এটলাছ টামাজাইট',
        'udm' => 'উদমুৰ্ত',
        'ug' => 'উইঘুৰ',
        'uk' => 'ইউক্ৰেইনীয়',
        'umb' => 'উম্বুন্দু',
        'ur' => 'উৰ্দু',
        'uz' => 'উজবেক',
        'vai' => 'ভাই',
        've' => 'ভেণ্ডা',
        'vi' => 'ভিয়েটনামী',
        'vo' => 'ভোলাপুক',
        'vun' => 'ভুঞ্জু',
        'wa' => 'ৱালুন',
        'wae' => 'ৱালছেৰ',
        'wal' => 'ওলেইটা',
        'war' => 'ৱাৰে',
        'wo' => 'ৱোলাফ',
        'wuu' => 'ৱু চাইনিজ',
        'xal' => 'কাল্মিক',
        'xh' => 'হোছা',
        'xog' => 'ছোগা',
        'yav' => 'য়াংবেন',
        'ybb' => 'য়েম্বা',
        'yi' => 'ইদ্দিছ',
        'yo' => 'ইউৰুবা',
        'yrl' => 'হিংগাটো',
        'yue' => 'কেণ্টোনীজ',
        'zgh' => 'ষ্টেণ্ডাৰ্ড মোৰোক্কান তামাজাইট',
        'zh' => 'চীনা',
        'zu' => 'ঝুলু',
        'zun' => 'ঝুনি',
        'zza' => 'ঝাঝা',
    ],
    'LocalizedNames' => [
        'ar_001' => 'আধুনিক মানক আৰবী',
        'de_AT' => 'অষ্ট্ৰেলিয়ান জাৰ্মান',
        'de_CH' => 'ছুইচ হাই জাৰ্মান',
        'en_AU' => 'অষ্ট্ৰেলিয়ান ইংৰাজী',
        'en_CA' => 'কানাডিয়ান ইংৰাজী',
        'en_GB' => 'ব্ৰিটিছ ইংৰাজী',
        'en_US' => 'আমেৰিকান ইংৰাজী',
        'es_419' => 'লেটিন আমেৰিকান স্পেনিচ',
        'es_ES' => 'ইউৰোপীয়ান স্পেনিচ',
        'es_MX' => 'মেক্সিকান স্পেনিচ',
        'fa_AF' => 'দাৰি',
        'fr_CA' => 'কানাডিয়ান ফ্ৰেন্স',
        'fr_CH' => 'ছুইচ ফ্ৰেন্স',
        'nl_BE' => 'ফ্লেমিচ',
        'pt_BR' => 'ব্ৰাজিলিয়ান পৰ্তুগীজ',
        'pt_PT' => 'ইউৰোপীয়ান পৰ্তুগীজ',
        'ro_MD' => 'মোল্ডাভিয়ান',
        'sw_CD' => 'কঙ্গো স্বাহিলি',
        'zh_Hans' => 'সৰলীকৃত চীনা',
        'zh_Hant' => 'পৰম্পৰাগত চীনা',
    ],
];
